@@ -21,8 +21,8 @@
 #include "invitation.h"
 
 #include "manageinvitations.h"
-#include "personalinvitation.h"
-#include "invite.h"
+#include "personalinvitedialog.h"
+#include "invitedialog.h"
 
 #include <dcopref.h>
 #include <kconfig.h>
@@ -31,6 +31,8 @@
 #include <qvalidator.h>
 #include <qstring.h>
 
+#include <dcopobject.h>
+
 enum krfb_mode {
 	KRFB_UNKNOWN_MODE = 0,
 	KRFB_KINETD_MODE,
@@ -44,11 +46,12 @@ enum krfb_mode {
  * standalone-config-dialog and all the invitation dialogs
  * @author Tim Jansen
  */
-class Configuration : public QObject {
+class Configuration : public QObject, public DCOPObject {
+		K_DCOP
    	Q_OBJECT
 public:
 	Configuration(krfb_mode mode);
-	~Configuration();
+	virtual ~Configuration();
 
 	krfb_mode mode() const;
 	bool askOnConnect() const;
@@ -104,8 +107,8 @@ private:
 	krfb_mode m_mode;
 
 	ManageInvitationsDialog invMngDlg;
-	InvitationDialog invDlg;
-	PersonalInvitationDialog persInvDlg;
+	InviteDialog invDlg;
+	PersonalInviteDialog persInvDlg;
 	QTimer refreshTimer;
 
 	bool askOnConnectFlag;
@@ -122,13 +125,15 @@ private:
 
 	bool disableBackgroundFlag;
 	bool disableXShmFlag;
+
+k_dcop:
+    // Connected to the DCOP signal
+    void updateKConfig();	
 private slots:
         void refreshTimeout();
 
 	void invMngDlgDeleteOnePressed();
 	void invMngDlgDeleteAllPressed();
-
-	void changeInvDlgNum(int newNum);
 };
 
 #endif
