@@ -67,50 +67,82 @@ bool Status::generateStatsWidget ()
     temp2 = "%1";
   if (freq >= 1000000000)
     {
-           if (freq / 1000000. >= 5785.)
+      if (freq / 1000000. > 5690.)
         {
-          temp3 = temp3.arg(161);
+          temp3 = temp3.arg(140);
         }
-      else if (freq / 1000000. >= 5765.)
+      else if (freq / 1000000. > 5670.)
         {
-          temp3 = temp3.arg(157);
+          temp3 = temp3.arg(136);
         }
-      else if (freq / 1000000. > 5745.)
+      else if (freq / 1000000. > 5650.)
         {
-          temp3 = temp3.arg(153);
+          temp3 = temp3.arg(132);
         }
-      else if (freq / 1000000. >= 5320.)
+      else if (freq / 1000000. > 5630.)
         {
-          temp3 = temp3.arg(149);
+          temp3 = temp3.arg(128);
         }
-      else if (freq / 1000000. > 5300.)
+      else if (freq / 1000000. > 5610.)
+        {
+          temp3 = temp3.arg(124);
+        }
+      else if (freq / 1000000. > 5590.)
+        {
+          temp3 = temp3.arg(120);
+        }
+      else if (freq / 1000000. > 5570.)
+        {
+          temp3 = temp3.arg(116);
+        }
+      else if (freq / 1000000. > 5550.)
+        {
+          temp3 = temp3.arg(112);
+        }
+      else if (freq / 1000000. > 5530.)
+        {
+          temp3 = temp3.arg(108);
+        }
+      else if (freq / 1000000. > 5510.)
+        {
+          temp3 = temp3.arg(104);
+        }
+      else if (freq / 1000000. > 5490.)
+        {
+          temp3 = temp3.arg(100);
+        }
+      else if (freq / 1000000. > 5310.)
         {
           temp3 = temp3.arg(64);
         }
-      else if (freq / 1000000. > 5280.)
+      else if (freq / 1000000. > 5290.)
         {
           temp3 = temp3.arg(60);
         }
-      else if (freq / 1000000. > 5260.)
+      else if (freq / 1000000. > 5270.)
         {
           temp3 = temp3.arg(56);
         }
-      else if (freq / 1000000. > 5240.)
+      else if (freq / 1000000. > 5250.)
         {
           temp3 = temp3.arg(52);
         }
-      else if (freq / 1000000. > 5220.)
+      else if (freq / 1000000. > 5230.)
         {
           temp3 = temp3.arg(48);
         }
-      else if (freq / 1000000. > 5200.)
+      else if (freq / 1000000. > 5210.)
         {
           temp3 = temp3.arg(44);
         }
-      else if (freq / 1000000. > 5180.)
+      else if (freq / 1000000. > 5190.)
         {
           temp3 = temp3.arg(40);
         }
+      else if (freq / 1000000. > 5170.)
+        {
+          temp3 = temp3.arg(36);
+        }
       else if (freq / 1000000. > 2474.)
 	{
 	  temp3 = temp3.arg (14);
@@ -173,8 +205,83 @@ bool Status::generateStatsWidget ()
     }
 
   if (freq < 1000000000)
-    {
-      if (freq >= 14.)
+    {if (freq >= 140.)
+	{
+	  temp2 = temp2.arg (5.700);
+	}
+      else if (freq >= 136.)
+	{
+	  temp2 = temp2.arg (5.680);
+	}
+      else if (freq >= 132.)
+	{
+	  temp2 = temp2.arg (5.660);
+	}
+      else if (freq >= 128.)
+	{
+	  temp2 = temp2.arg (5.640);
+	}
+      else if (freq >= 124.)
+	{
+	  temp2 = temp2.arg (5.620);
+	}
+      else if (freq >= 120.)
+	{
+	  temp2 = temp2.arg (5.600);
+	}
+      else if (freq >= 116.)
+	{
+	  temp2 = temp2.arg (5.580);
+	}
+      else if (freq >= 112.)
+	{
+	  temp2 = temp2.arg (5.560);
+	}
+      else if (freq >= 108.)
+	{
+	  temp2 = temp2.arg (5.540);
+	}
+      else if (freq >= 104.)
+	{
+	  temp2 = temp2.arg (5.520);
+	}
+      else if (freq >= 100.)
+	{
+	  temp2 = temp2.arg (5.500);
+	}
+      else if (freq >= 64.)
+	{
+	  temp2 = temp2.arg (5.320);
+	}
+      else if (freq >= 60.)
+	{
+	  temp2 = temp2.arg (5.300);
+	}
+      else if (freq >= 56.)
+	{
+	  temp2 = temp2.arg (5.280);
+	}
+      else if (freq >= 52.)
+	{
+	  temp2 = temp2.arg (5.260);
+	}
+      else if (freq >= 48.)
+	{
+	  temp2 = temp2.arg (5.240);
+	}
+      else if (freq >= 44.)
+	{
+	  temp2 = temp2.arg (5.220);
+	}
+      else if (freq >= 40.)
+	{
+	  temp2 = temp2.arg (5.200);
+	}
+      else if (freq >= 36.)
+	{
+	  temp2 = temp2.arg (5.180);
+	}
+      else if (freq >= 14.)
 	{
 	  temp2 = temp2.arg (2.484);
 	}
